@@ -824,7 +824,7 @@ class mesh(_layered_object):
             lay.column_cell = {}
             for col in lay.column:
                 c = cell(lay, col)
-                cell_type = cell.num_nodes
+                cell_type = c.num_nodes
                 if cell_type not in cells: cells[cell_type] = []
                 cells[cell_type].append(c)
                 lay.cell.append(c)
@@ -976,14 +976,14 @@ class mesh(_layered_object):
                 dset.attrs['description'] = 'Layer boundary elevations, ' + \
                                             'from top to bottom'
             if self.node:
-                max_col_nodes = max([col.num_nodes for col in self.column])
                 pos = np.array([n.pos for n in self.node])
                 node_group = f.create_group('node')
                 dset = node_group.create_dataset('position', data = pos)
                 dset.attrs['description'] = 'Position of each node'
                 if self.column:
+                    max_col_nodes = max([col.num_nodes for col in self.column])
                     col_node_indices = np.full((self.num_columns, max_col_nodes), -1,
-                                               dtype = np.int)
+                                               dtype = int)
                     for i, col in enumerate(self.column):
                         col_node_indices[i, 0: col.num_nodes] = [n.index for n in col.node]
                     col_group = f.create_group('column')
